#!/bin/bash

declare -r CRYPTOPLUGIN_DIR=/opt/aktivco/rutokenplugin
declare -r GUEST_ROOT_DIR=$CRYPTOPLUGIN_DIR/guestfs/x86_64
if [ ! -d $GUEST_ROOT_DIR ]
then
	echo "Guest FS root directory $GUEST_ROOT_DIR does not exist" >&2
	exit 1
fi

export LC_ALL=C

for RTC in /opt/mcst/rtc/rtc_opt_rel* /opt/mcst/rtc/bin/rtc_opt_rel* /usr/bin/rtc_opt_rel*
do
    IFS="_"
    set -- $RTC
    unset -v IFS

	if [[ $5 != "x64" ]]
	then
		continue
	fi

    declare -r MACHINE=$4
    break
done

if [ ! -v MACHINE ]
then
	echo "64-bit binary compiler is not found" >&2
	exit 2
fi

if [[ $MACHINE == p2 ]]
then
    declare -r DISABLE_L4=--disable_l4
fi

if [[ $MACHINE == e3s ]]
then
	echo "Execution of 64-bit guest code is not supported on this CPU" >&2
	exit 3
fi

declare -r MOZILLA_DIR=/usr/lib/mozilla
declare -r PKCS_PATH="$CRYPTOPLUGIN_DIR/librtpkcs11ecp.so"
declare -r BIND="-b /run/pcscd -b /var/run/pcscd -b $CRYPTOPLUGIN_DIR/FireWyrmNativeMessageHost -b $CRYPTOPLUGIN_DIR/libnpRutokenPlugin.so -b $CRYPTOPLUGIN_DIR/librtpkcs11ecp.so -b $MOZILLA_DIR -b /run/nscd/socket"

exec $RTC ${DISABLE_L4:-""} ${BIND} --log /var/log/rtc$GUEST_ROOT_DIR --path_prefix $GUEST_ROOT_DIR -- $CRYPTOPLUGIN_DIR/FireWyrmNativeMessageHost $PKCS_PATH
